<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 02/12/2004 *
 * ================                             Last change: 11/12/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-theme_import.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Import of new themes                             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Importieren von neuen Themes                     *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!IS_ADMIN())) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} elseif (!EXT_IS_ACTIVE("theme")) {
	addFatalMessage(sprintf(EXTENSION_PROBLEM_NOT_INSTALLED, "theme"));
	return;
}

// Add description as navigation point
ADD_DESCR("admin", __FILE__);

// Switch to testing mode
$THEME_MODE = "test";

// Import selected theme if not present
if (!empty($_POST['theme'])) {
	// Check if theme is there
	if (!THEME_CHECK_EXIST($_POST['theme'])) {
		// Import theme
		$INC = sprintf("theme/%s/theme.php", SQL_ESCAPE($_POST['theme']));
		if (FILE_READABLE($INC)) {
			// Load the theme header file
			LOAD_INC($INC);

			// Register it ith the exchange
			SQL_QUERY_ESC("INSERT INTO `{!_MYSQL_PREFIX!}_themes` (`theme_path`, `theme_active`, `theme_ver`, `theme_name`)
VALUES ('%s','N','%s','%s')",
				array($_POST['theme'], $THEME_VERSION, $THEME_NAME), __FILE__, __LINE__);

			// Destroy cache
			REBUILD_CACHE("themes", "them");

			// Prepare message
			$msg = ADMIN_THEME_IMPORTED_1.$_POST['theme'].ADMIN_THEME_IMPORTED_2;
		} else {
			// Include file not found!
			$msg = ADMIN_THEME_INC_404_1.$_POST['theme'].ADMIN_THEME_INC_404_2;
		}
	} else {
		// Theme already imported
		$msg = ADMIN_THEME_ALREADY_1.$_POST['theme'].ADMIN_THEME_ALREADY_2;
	}

	// Output message
	LOAD_TEMPLATE("admin_settings_saved", false, $msg);
	OUTPUT_HTML("<br />");
} // END - if

// Initialize array
$THEMES = array(
	'theme_unix'   => array(), // Unix name from filesystem
	'theme_name'   => array(), // Title
	'theme_author' => array(), // Theme author's name
	'theme_email'  => array(), // Author's email address
	'theme_url'    => array(), // URL were you can download it from
	'theme_ver'    => array(), // Version number of theme
);

// Read directory "themes"
$handle = opendir(PATH."theme/") or mxchange_die("Cannot read themes dir!");
while ($dir = readdir($handle)) {
	// Construct absolute theme.php file name
	$INC = sprintf("theme/%s/theme.php", $dir);

	// Test it...
	if (($dir != ".") && ($dir != "..") && (FILE_READABLE($INC))) {
		// Found a valid directory so let's load it's theme.php file
		LOAD_INC($INC);

		// Add found theme to array
		$THEMES['theme_unix'][]   = $dir;
		$THEMES['theme_name'][]   = $THEME_NAME;
		$THEMES['theme_author'][] = $THEME_AUTHOR;
		$THEMES['theme_email'][]  = $THEME_EMAIL;
		$THEMES['theme_url'][]    = $THEME_URL;
		$THEMES['theme_ver'][]    = $THEME_VERSION;
	} // END - if
} // END - while

// Close directory
closedir($handle);

// Sort array by Uni* name
array_pk_sort($THEMES, array("theme_name"));

// Generate output lines for the template
$OUT = ""; $SW = 2;
foreach ($THEMES['theme_unix'] as $key => $unix) {
	// Check if current theme is already imported or not
	if (THEME_CHECK_EXIST($unix)) {
		// Already installed
		$FOUND = "<div class=\"admin_note\">{!ADMIN_THEME_ALREADY_INSTALLED!}</div>";
	} else {
		// Theme not installed
		$FOUND = "<form action=\"{!URL!}/modules.php?module=admin&amp;what=theme_import\" method=\"POST\">
  <input type=\"submit\" name=\"ok\" class=\"admin_submit\" value=\"{!ADMIN_INSTALL_THEME!}\" />
  <input type=\"hidden\" name=\"theme\" value=\"".$unix."\" />
</form>";
	}

	// Add row
	$OUT .= "<tr>
  <td class=\"switch_sw".$SW." bottom2 right2\" align=\"center\" height=\"30\">".$unix."</td>
  <td class=\"switch_sw".$SW." bottom2 right2\" align=\"center\">".$THEMES['theme_name'][$key]."</td>
  <td class=\"switch_sw".$SW." bottom2 right2\" align=\"center\">
    <a href=\"mailto:".$THEMES['theme_email'][$key]."?Subject=[Theme:] ".$THEMES['theme_name'][$key]." (".$unix.")"."\">".$THEMES['theme_author'][$key]."</a>
  </td>
  <td class=\"switch_sw".$SW." bottom2 right2\" align=\"center\">
    <a href=\"".DEREFERER($THEMES['theme_url'][$key])."\" target=\"_blank\">".$THEMES['theme_url'][$key]."</a>
  </td>
  <td class=\"switch_sw".$SW." bottom2 right2\" align=\"center\">v".$THEMES['theme_ver'][$key]."</td>
  <td class=\"switch_sw".$SW." bottom2\" align=\"center\">
    ".$FOUND."
  </td>
</tr>\n";

	// Switch color
	$SW = 3 - $SW;
}

if (empty($OUT)) {
	// No themes found???
	$OUT .= "<tr>
  <td colspan=\"6\" class=\"bottom2\" height=\"80\">
    ".LOAD_TEMPLATE("admin_settings_saved", true, getMessage('ADMIN_NO_THEMES_FOUND'))."
  </td>
</tr>\n";
} // END - if
define('__THEME_LIST', $OUT);

// Load template
LOAD_TEMPLATE("admin_theme_import");

//
?>
